@@ -1078,6 +1078,8 @@ run_menu(void)
 	  strncat(newcmdline, tail_cmdline, MAX_CMDLINE_LEN-1);
 	  cmdline = edit_cmdline(newcmdline, top);
 	  done = !!cmdline;
+	  if ( done )
+	     tail_cmdline[0] = NULL;
 	  clear = 1;		/* In case we hit [Esc] and done is null */
 	} else {
 	  draw_row(entry-top+4+VSHIFT, entry, top, 0, 0);
